psipy
=====

psipy is a package for loading and visualising the output of PSI's MAS model
runs.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   guide/installing
   guide/getting_started
   auto_examples/index
   reference/api
   developer/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
